@@ -315,7 +315,7 @@ vforecast.1d.ssa <- function(x, groups, len = 1,
       Z[j, ] <- P %*% Z[j - 1, ]
     }
 
-    res <- rowSums(.hankelize.multi(Uet, Z, fft.plan))
+    res <- rowSums(.hankelize.multi(Uet, Z, fft.plan = fft.plan))
 
     out[[i]] <- res[(if (only.new) (K+L):N.res else 1:N.res)]
     out[[i]] <- .apply.attributes(x, out[[i]],
@@ -386,7 +386,7 @@ vforecast.mssa <- function(x, groups, len = 1,
 
           rowSums(.hankelize.multi(Uet,
                                    Z,
-                                   fft.plan[[idx]]))
+                                   fft.plan = fft.plan[[idx]]))
         })
     } else if (identical(direction, "row")) {
       V.head <- Vet[-cK, , drop = FALSE]
@@ -404,7 +404,7 @@ vforecast.mssa <- function(x, groups, len = 1,
       R <- lapply(seq_along(N), function(idx) {
           rowSums(.hankelize.multi(Z[1 : (L + len + K[idx] - 1), , drop = FALSE],
                                    Vet[cKs[idx] : cK[idx], , drop = FALSE],
-                                   fft.plan[[idx]]))
+                                   fft.plan = fft.plan[[idx]]))
         })
     }
 
