@@ -33,9 +33,16 @@ panel.reconstruction.2d.ssa <- function(x, y, z, recon, subscripts, at, ...,
                                         region, contour,
                                         fill.uncovered = "void",
                                         fill.color = NULL) {
+  if (is.list(fill.uncovered))
+    fill.uncovered <- fill.uncovered[[(subscripts - 1) %% length(fill.uncovered) + 1]]
+  if (is.list(fill.color))
+    fill.color <- fill.color[[(subscripts - 1) %% length(fill.color) + 1]]
   if (!is.null(fill.color))
     panel.fill(col = fill.color)
 
+  if (is.list(at))
+    at <- at[[(subscripts - 1) %% length(at) + 1]]
+
   panel <- if (.useRaster) panel.levelplot.raster else panel.levelplot
   N <- dim(recon[[subscripts]])
   data <- expand.grid(y = rev(seq_len(N[1])), x = seq_len(N[2]))
@@ -65,6 +72,10 @@ panel.reconstruction.2d.ssa <- function(x, y, z, recon, subscripts, at, ...,
     at <- seq(z.range[1], z.range[2], length.out = .cuts + 2)
   }
 
+  # Cutoff outstanding values
+  data$z[data$z < min(at)] <- min(at)
+  data$z[data$z > max(at)] <- max(at)
+
   panel(data$x, data$y, data$z, subscripts = seq_len(nrow(data)),
         at = at, contour = FALSE, region = TRUE, ...)
 
@@ -83,10 +94,14 @@ plot.2d.ssa.reconstruction <- function(x, ...,
                                        add.original = TRUE,
                                        add.residuals = TRUE,
                                        add.ranges,
+                                       col = grey(c(0, 1)),
+                                       zlim,
                                        at) {
   dots <- list(...)
   type <- match.arg(type)
 
+  if (!missing(zlim))
+    at <- "same"
   if (missing(at))
     at <- if (identical(type, "cumsum")) "same" else "free"
   if (is.character(at))
@@ -135,20 +150,21 @@ plot.2d.ssa.reconstruction <- function(x, ...,
                     as.table = TRUE,
                     scales = list(draw = FALSE, relation = "same"),
                     aspect = "iso",
-                    par.settings = list(regions = list(col = colorRampPalette(grey(c(0, 1))))),
                     cuts = 20,
-                    colorkey = !identical(at, "free"),
+                    colorkey = !(identical(at, "free") || (is.list(at) && length(at) > 1)),
                     symmetric = FALSE,
                     ref = FALSE,
                     useRaster = TRUE,
                     fill.uncovered = "void")
+  dots <- modifyList(dots,
+                     list(par.settings = list(regions = list(col = colorRampPalette(col)))))
 
   # Disable colorkey if subplots are drawing in different scales
-  if (identical(at, "free"))
+  if (identical(at, "free") || (is.list(at) && length(at) > 1))
     dots$colorkey <- FALSE
 
   if (identical(at, "same")) {
-    all.values <- unlist(x)
+    all.values <- if (missing(zlim)) unlist(x) else zlim
     at <- pretty(if (dots$symmetric) c(all.values, -all.values) else all.values, n = dots$cuts)
   }
 
@@ -193,9 +209,14 @@ panel.eigenvectors.2d.ssa <- function(x, y, z, ssaobj, subscripts, at, ...,
                                       .useRaster = FALSE,
                                       region, contour,
                                       fill.color = NULL) {
+  if (is.list(fill.color))
+    fill.color <- fill.color[[(subscripts - 1) %% length(fill.color) + 1]]
   if (!is.null(fill.color))
     panel.fill(col = fill.color)
 
+  if (is.list(at))
+    at <- at[[(subscripts - 1) %% length(at) + 1]]
+
   panel <- if (.useRaster) panel.levelplot.raster else panel.levelplot
 
   idx <- z[subscripts]
@@ -224,6 +245,10 @@ panel.eigenvectors.2d.ssa <- function(x, y, z, ssaobj, subscripts, at, ...,
     at <- seq(z.range[1], z.range[2], length.out = .cuts + 2)
   }
 
+  # Cutoff outstanding values
+  data$z[data$z < min(at)] <- min(at)
+  data$z[data$z > max(at)] <- max(at)
+
   panel(data$x, data$y, data$z, subscripts = seq_len(nrow(data)),
         at = at, contour = FALSE, region = TRUE, ...)
 
@@ -238,10 +263,18 @@ panel.eigenvectors.2d.ssa <- function(x, y, z, ssaobj, subscripts, at, ...,
 
 .plot.ssa.vectors.2d.ssa <- function(x, ...,
                                      what = c("eigen", "factor"),
-                                     plot.contrib = FALSE, idx, at) {
+                                     col = grey(c(0, 1)),
+                                     zlim,
+                                     at,
+                                     plot.contrib = FALSE, idx) {
   dots <- list(...)
   what <- match.arg(what)
 
+  if (max(idx) > nsigma(x))
+    stop("Too few eigentriples computed for this decomposition")
+
+  if (!missing(zlim))
+    at <- "same"
   if (missing(at))
     at <- "free"
   if (is.character(at))
@@ -250,17 +283,6 @@ panel.eigenvectors.2d.ssa <- function(x, y, z, ssaobj, subscripts, at, ...,
   # FIXME: check for proper lengths
   d <- data.frame(row = idx, column = idx, z = idx)
 
-  if (plot.contrib) {
-    # Check for F-orthogonality
-    isfcor <- .is.frobenius.orthogonal(x, idx, ...)
-    if (!isTRUE(isfcor))
-      warning(sprintf("Elementary matrices are not F-orthogonal (max F-cor is %s). Contributions can be irrelevant",
-                      format(isfcor, digits = 3)))
-
-    total <- wnorm(x)^2
-    sigma <- round(100*x$sigma[idx]^2 / total, digits = 2);
-  }
-
   # Provide convenient defaults
   dots <- .defaults(dots,
                     xlab = "",
@@ -269,18 +291,27 @@ panel.eigenvectors.2d.ssa <- function(x, y, z, ssaobj, subscripts, at, ...,
                     as.table = TRUE,
                     scales = list(draw = FALSE, relation = "same"),
                     aspect = "iso",
-                    par.settings = list(regions = list(col = colorRampPalette(grey(c(0, 1))))),
                     cuts = 20,
                     symmetric = FALSE,
                     ref = FALSE,
                     useRaster = TRUE)
+  dots <- modifyList(dots,
+                     list(par.settings = list(regions = list(col = colorRampPalette(col)))))
 
   # Disable colorkey if subplots are drawed in different scales
-  if (identical(at, "free"))
+  if (identical(at, "free") || (is.list(at) && length(at) > 1))
     dots$colorkey <- FALSE
 
   if (identical(at, "same")) {
-    all.values <- x$U[, idx]
+    if (missing(zlim)) {
+      if (identical(what, "eigen")) {
+        all.values <- range(.U(x)[, idx])
+      } else if (identical(what, "factor")) {
+        all.values <- range(calc.v(x, idx))
+      }
+    } else {
+      all.values <- zlim
+    }
     at <- pretty(if (dots$symmetric) c(all.values, -all.values) else all.values, n = dots$cuts)
   }
 
@@ -290,7 +321,7 @@ panel.eigenvectors.2d.ssa <- function(x, y, z, ssaobj, subscripts, at, ...,
 
   do.call("levelplot",
           c(list(x = z ~ row * column | factor(z,
-                                               labels = if (!plot.contrib) z else paste(z, " (", sigma, "%)", sep = "")),
+                                               labels = if (!plot.contrib) z else paste(z, " (", .contribution(x, z, ...), "%)", sep = "")),
                  data = d, ssaobj = x,
                  what = what,
                  at = at,
