@@ -151,8 +151,10 @@ decompose.pssa <- function(x,
     A <- function(x, args) ematmul(args, x)
     Atrans <- function(x, args) ematmul(args, x, transposed = TRUE)
     S <- RSpectra::svds(A, k = neig, Atrans = Atrans, dim = dim(h), args = h, ...)
+    ## RSpectra sometimes returns unsorted results
+    idx <- order(S$d, decreasing = TRUE)
     .set.decomposition(x,
-                       sigma = c(ssigma, S$d), U = cbind(sU, S$u), V = cbind(sV, S$v))
+                       sigma = c(ssigma, S$d[idx]), U = cbind(sU, S$u[, idx]), V = cbind(sV, S$v[, idx]))
   } else if (identical(x$svd.method, "primme")) {
     if (!requireNamespace("PRIMME", quietly = TRUE))
         stop("PRIMME package is requireNamespaced for SVD method `primme'")
@@ -161,6 +163,20 @@ decompose.pssa <- function(x,
     S <- PRIMME::svds(pA, NSvals = neig, m = nrow(h), n = ncol(h), isreal = TRUE, ...)
     .set.decomposition(x,
                        sigma = c(ssigma, S$d), U = cbind(sU, S$u), V = cbind(sV, S$v))
+  } else if (identical(x$svd.method, "irlba")) {
+    if (!requireNamespace("irlba", quietly = TRUE))
+        stop("irlba package is required for SVD method `irlba'")
+    h <- .get.or.create.phmat(x)
+    S <- irlba::irlba(h, nv = neig, ...)
+    .set.decomposition(x,
+                       sigma = c(ssigma, S$d), U = cbind(sU, S$u), V = cbind(sV, S$v))
+  } else if (identical(x$svd.method, "rsvd")) {
+    if (!requireNamespace("irlba", quietly = TRUE))
+        stop("irlba package is required for SVD method `rsvd'")
+    h <- .get.or.create.phmat(x)
+    S <- irlba::svdr(h, k = neig, ...)
+    .set.decomposition(x,
+                       sigma = c(ssigma, S$d), U = cbind(sU, S$u), V = cbind(sV, S$v))
   } else
     stop("unsupported SVD method")
 
@@ -382,7 +398,7 @@ vforecast.pssa.1d.ssa <- function(x, groups, len = 1,
       Z[j, ] <- P %*% Z[j - 1, ]
     }
 
-    res <- rowSums(.hankelize.multi(Uet, Z, fft.plan))
+    res <- rowSums(.hankelize.multi(Uet, Z, fft.plan = fft.plan))
 
     out[[i]] <- res[(if (only.new) (K+L):N.res else 1:N.res)]
     out[[i]] <- .apply.attributes(x, out[[i]],
